@@ -25,7 +25,11 @@ def format_list(obj: list[Value], *, sort: bool = False) -> str:
 
 
 def parse_list(obj: str) -> list[str]:
-    return [e for e in obj.removeprefix("|").removesuffix("|").split("||") if e]
+    return obj.removeprefix("|").removesuffix("|").split("||")
+
+
+def parse_list_filter_empty(obj: str) -> list[str]:
+    return list(filter(bool, obj.removeprefix("|").removesuffix("|").split("||")))
 
 
 def type_to_sql(t: type) -> str:
@@ -98,8 +102,8 @@ def default_parser(t: Type[T]) -> Callable[[Value], T]:
     elif t_ is datetime:
         return lambda v: datetime.strptime(v, date_format) if v is not None else None
     elif t_ in (list, tuple, set):
-        return (lambda v: t_(map(sub_type, parse_list(v))) if v is not None else None) if sub_type else (
-            lambda v: t_(parse_list(v)) if v is not None else None)
+        return (lambda v: t_(map(sub_type, parse_list_filter_empty(v))) if v is not None else None) if sub_type else (
+            lambda v: t_(parse_list_filter_empty(v)) if v is not None else None)
     elif t_ is dict:
         return lambda v: loads(v) if v is not None else None
     else:
