@@ -508,7 +508,7 @@ def update_5_3(conn: Connection, _db_path: Path, db_new_path: Path) -> list[str]
 
 
 # noinspection SqlResolve,SqlNoDataSourceInspection,DuplicatedCode,SqlWithoutWhere
-def update_5_3_2(conn: Connection, _db_path: Path, db_new_path: Path) -> list[str]:
+def update_5_3_4(conn: Connection, _db_path: Path, db_new_path: Path) -> list[str]:
     make_database_5_3(connect(db_new_path)).close()
     conn.execute("attach database ? as db_new", [str(db_new_path)])
     conn.execute("insert into db_new.USERS select * from USERS")
@@ -517,13 +517,14 @@ def update_5_3_2(conn: Connection, _db_path: Path, db_new_path: Path) -> list[st
     conn.execute("insert into db_new.COMMENTS select * from COMMENTS")
     conn.execute("insert into db_new.HISTORY select * from HISTORY")
     conn.execute("insert or replace into db_new.SETTINGS select * from SETTINGS where SETTING != 'VERSION'")
-    conn.execute("update db_new.SETTINGS set SVALUE = '5.3.2' where SETTING = 'VERSION'")
+    conn.execute("update db_new.SETTINGS set SVALUE = '5.3.4' where SETTING = 'VERSION'")
 
     def tiered_path(i: int | str, depth: int = 5, width: int = 2) -> Path:
         id_str: str = str(int(i)).zfill(depth * width)
         return Path(*[id_str[n_:n_ + width] for n_ in range(0, depth * width, width)])
 
     files_folder: Path = Path(conn.execute("select SVALUE from SETTINGS where SETTING = 'FILESFOLDER'").fetchone()[0])
+    files_folder = files_folder if files_folder.is_absolute() else (db_new_path.parent / files_folder)
     submissions = conn.execute("""select ID, FILEEXT from db_new.SUBMISSIONS
         where FILEEXT like '%|||%' or FILEEXT like '%||' order by ID""")
     submissions_fixed: int = 0
@@ -535,7 +536,7 @@ def update_5_3_2(conn: Connection, _db_path: Path, db_new_path: Path) -> list[st
             ext_new = ext.removesuffix("|")
             file = folder / f"submission{n if n else ''}.{ext}"
             if file.is_file():
-                file.replace(file.with_suffix(ext_new))
+                file.replace(file.with_suffix(f'.{ext_new}' if ext_new else ''))
             exts[n] = ext_new
         conn.execute("update db_new.SUBMISSIONS set FILEEXT = ? where ID = ?", [f"|{'|'.join(exts)}|", id_])
         submissions_fixed += 1
@@ -605,8 +606,8 @@ def update_database(conn: Connection, version: str) -> Connection:
         conn = update_wrapper(conn, update_5_2_2, db_version, v)  # 5.2.0-5.2.1 to 5.2.2
     elif compare_versions(db_version, v := "5.3.0") < 0:
         conn = update_wrapper(conn, update_5_3, db_version, v)  # 5.2.2 to 5.3.0
-    elif compare_versions(db_version, v := "5.3.2") < 0:
-        conn = update_wrapper(conn, update_5_3_2, db_version, v)  # 5.3.0 to 5.3.2
+    elif compare_versions(db_version, v := "5.3.4") < 0:
+        conn = update_wrapper(conn, update_5_3_4, db_version, v)  # 5.3.0 to 5.3.4
     elif compare_versions(db_version, version) < 0:
         return update_patch(conn, db_version, version)  # Update to the latest patch
 
